/// <reference types="node" resolution-mode="require"/>
import { AztecAddress } from '../aztec-address/index.js';
import { BufferReader } from '../serialize/buffer_reader.js';
/**
 * Fr represents a field of integers modulo the prime number MODULUS.
 * It provides utility functions to work with elements in this field, such as conversions between different representations and checks for equality and zero values. The elements can be serialized to and deserialized from byte buffers or strings.
 * Some use cases include working with cryptographic operations and finite fields.
 */
export declare class Fr {
    static ZERO: Fr;
    static MODULUS: bigint;
    static MAX_VALUE: bigint;
    static SIZE_IN_BYTES: number;
    /**
     * The numeric value of the field element as a bigint.
     */
    readonly value: bigint;
    constructor(value: boolean | bigint | number | Fr | AztecAddress);
    /**
     * Generates a random Fr or Fq instance with a value modulo the respective class' MODULUS.
     * This method uses randomBytes to generate a random 32-byte buffer, converts it to a bigint
     * and takes the modulus of the result with the class' MODULUS constant.
     *
     * @returns A new Fr or Fq instance with a random value.
     */
    static random(): Fr;
    /**
     * Returns a new zero-value field.
     * @returns A new zero-value field.
     */
    static zero(): Fr;
    /**
     * Create an instance of the corresponding class (Fr or Fq) from a Buffer or a BufferReader.
     * Reads 'SIZE_IN_BYTES' bytes from the given Buffer or BufferReader and constructs an instance with the decoded value.
     * If the input is a Buffer, it is internally converted to a BufferReader before reading.
     * Throws an error if the input length is invalid or the decoded value is out of range.
     *
     * @param buffer - The Buffer or BufferReader containing the bytes representing the value.
     * @returns An instance of the corresponding class (Fr or Fq) with the decoded value.
     */
    static fromBuffer(buffer: Buffer | BufferReader): Fr;
    /**
     * Create a Fr instance from a hex-encoded string.
     * The input 'address' can be either prefixed with '0x' or not, and should have exactly 64 hex characters.
     * Throws an error if the input length is invalid or the address value is out of range.
     *
     * @param address - The hex-encoded string representing the field element.
     * @returns A Fr instance.
     */
    static fromString(address: string): Fr;
    /**
     * Converts the value of the instance to a buffer with a specified length.
     * The method uses the provided value and size in bytes to create a buffer representation
     * of the numeric value. This can be useful for serialization and communication purposes.
     *
     * @returns A buffer representing the instance's value.
     */
    toBuffer(): Buffer;
    /**
     * Converts the value of the Fr or Fq class instance to a hexadecimal string.
     * The resulting string is prefixed with '0x' and represents the bigint value
     * in base 16.
     *
     * @param padTo32 - Whether to pad the string to 32 bytes.
     * @returns A hex-encoded string representing the value of the class instance.
     */
    toString(padTo32?: boolean): `0x${string}`;
    /**
     * Retrieves the underlying bigint.
     * This method mostly exists to match user expectations, as value is already public.
     * @returns The underlying bigint.
     */
    toBigInt(): bigint;
    /**
     * Returns a shortened string representation of the Fr value, formatted with '0x' prefix and ellipsis in the middle.
     * The resulting string has first 10 characters (including '0x') and last 4 characters of the full hexadecimal value.
     *
     * @returns A shorter, human-readable string representation of the Fr value.
     */
    toShortString(): string;
    /**
     * Checks if the provided Fr instance is equal to the current instance.
     * Two instances are considered equal if their 'value' properties are the same.
     *
     * @param rhs - The Fr instance to compare with the current instance.
     * @returns A boolean indicating whether the two instances are equal.
     */
    equals(rhs: Fr): boolean;
    /**
     * Check if the instance value is zero.
     * The method returns true if the value of the instance is 0n (zero in BigInt representation),
     * otherwise, it returns false.
     *
     * @returns A boolean indicating whether the instance value is zero or not.
     */
    isZero(): boolean;
    /**
     * Converts the current value of the Fq or Fr instance to a friendly JSON representation.
     * The output will be a hexadecimal string prefixed with '0x'.
     *
     * @returns A '0x' prefixed hexadecimal string representing the current value.
     */
    toFriendlyJSON(): `0x${string}`;
}
/**
 * Fq represents a field element in a prime finite field with modulus defined by the constant MODULUS.
 * It provides methods for creating, manipulating, and comparing field elements, as well as converting
 * them to/from different data types like Buffers and hex strings. Field elements are used in various
 * cryptographic protocols and operations, such as elliptic curve cryptography.
 *
 * @example
 * const fqElem = new Fq(BigInt("123456789"));
 * const randomFqElem = Fq.random();
 * const fromBufferFqElem = Fq.fromBuffer(buffer);
 */
export declare class Fq {
    /**
     * The element's value as a bigint in the finite field.
     */
    readonly value: bigint;
    static MODULUS: bigint;
    static MAX_VALUE: bigint;
    static SIZE_IN_BYTES: number;
    constructor(
    /**
     * The element's value as a bigint in the finite field.
     */
    value: bigint);
    /**
     * Generates a random Fr or Fq instance with a value within the range of their respective modulus.
     * The random value is generated from a byte array of length equal to SIZE_IN_BYTES, then truncated
     * to the appropriate modulus before creating the new Fr or Fq instance.
     *
     * @returns A new Fr or Fq instance with a randomly generated value.
     */
    static random(): Fq;
    /**
     * Create an instance of the calling class (Fr or Fq) from a given buffer or BufferReader.
     * Reads SIZE_IN_BYTES from the provided buffer and converts it to a bigint, then creates a new instance
     * with that value. Throws an error if the value is out of range for the calling class.
     *
     * @param buffer - The input buffer or BufferReader containing the bytes representing the value.
     * @returns An instance of the calling class (Fr or Fq) initialized with the bigint value.
     */
    static fromBuffer(buffer: Buffer | BufferReader): Fq;
    /**
     * Converts the bigint value of the instance to a Buffer representation.
     * The output buffer has a fixed size, determined by the 'SIZE_IN_BYTES' constant.
     *
     * @returns A Buffer containing the byte representation of the instance's value.
     */
    toBuffer(): Buffer;
    /**
     * Converts the Fq value to a hexadecimal string representation.
     * The resulting string is prefixed with '0x' and contains the exact number of hex characters required
     * to represent the numeric value of this instance.
     *
     * @returns A hexadecimal string representing the Fq value.
     */
    toString(): `0x${string}`;
    /**
     * Check if the value of the current instance is zero.
     * This function compares the internal 'value' property with 0n (BigInt representation of zero).
     * Returns true if the value is zero, otherwise returns false.
     *
     * @returns A boolean indicating whether the value is zero or not.
     */
    isZero(): boolean;
    /**
     * Converts the value of the Fr or Fq instance to a friendly JSON format.
     * The output is a hexadecimal string representation of the value with '0x' prefix.
     *
     * @returns A string representing the value in the JSON format.
     */
    toFriendlyJSON(): `0x${string}`;
}
//# sourceMappingURL=fields.d.ts.map